@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 """
 Polaroid
 ~~~~~~~~~~~~~~~~~~~
@@ -8,18 +7,18 @@ Hyper Fast and safe image manipulation library for python . Powered by rust.
 :license: MIT, see LICENSE for more details.
 """
 
-from .polaroid import Image,Gif
+from .polaroid import Image,Gif, Rgb
 from collections import namedtuple
 
-__version__ = '0.2.5'
+__version__ = '0.2.7'
 __author__ = "Daggy1234"
 __license__ = "MIT"
 __copyright__ = "Copyright 2020 Daggy1234"
 
-__all__ = ["Image","Gif"]
+__all__ = ["Image","Gif","Rgb"]
 
 VersionInfo = namedtuple('VersionInfo',
                          'major minor micro releaselevel serial')
 
-version_info = VersionInfo(major=0, minor=2, micro=5, releaselevel='development',
+version_info = VersionInfo(major=0, minor=2, micro=7, releaselevel='development',
                            serial=0)
\ No newline at end of file
